#!/usr/bin/env node

import { spawn } from 'child_process';
import { highlightLine } from '../lib/parser.js';
import chalk from 'chalk';

const args = process.argv.slice(2);
if (args.length === 0) {
  console.log('Usage: logview \"<command>\"');
  process.exit(1);
}

const child = spawn(args.join(' '), { shell: true });

function formatWithCollapse(lines) {
  let stackBuffer = [];
  let inStack = false;
  const output = [];

  lines.forEach((line) => {
    if (/^\s*at\s/.test(line)) {
      stackBuffer.push(line);
      inStack = true;
    } else {
      if (inStack && stackBuffer.length > 3) {
        output.push(chalk.gray(`[📦 Stack trace de ${stackBuffer.length} líneas colapsado]`));
      } else {
        output.push(...stackBuffer.map(l => chalk.dim(l)));
      }
      stackBuffer = [];
      inStack = false;
      output.push(highlightLine(line));
    }
  });

  // por si queda un stack al final sin cerrar
  if (stackBuffer.length) {
    if (stackBuffer.length > 3) {
      output.push(chalk.gray(`[📦 Stack trace de ${stackBuffer.length} líneas colapsado]`));
    } else {
      output.push(...stackBuffer.map(l => chalk.dim(l)));
    }
  }

  return output;
}

child.stdout.on('data', (data) => {
  const lines = data.toString().split('\n');
  formatWithCollapse(lines).forEach((line) => console.log(line));
});

child.stderr.on('data', (data) => {
  const lines = data.toString().split('\n');
  formatWithCollapse(lines).forEach((line) => console.log(line));
});
